==> angelscript_2.33.0.zip: sdk/docs/manual/doc_script_class.js <==
var doc_script_class =
[
    [ "Script class overview", "doc_script_class_desc.html", [
      [ "Class constructors", "doc_script_class_desc.html#doc_script_class_construct", null ],
      [ "Class destructor", "doc_script_class_desc.html#doc_script_class_destruct", null ],
      [ "Const methods", "doc_script_class_desc.html#doc_script_class_const", null ]
    ] ],
    [ "Inheritance and polymorphism", "doc_script_class_inheritance.html", [
      [ "Extra control with final, abstract, and override", "doc_script_class_inheritance.html#doc_script_class_inheritance_2", null ]
    ] ],
    [ "Protected and private class members", "doc_script_class_private.html", null ],
    [ "Operator overloads", "doc_script_class_ops.html", [
      [ "Prefixed unary operators", "doc_script_class_ops.html#doc_script_class_unary_ops", null ],
      [ "Postfixed unary operators", "doc_script_class_ops.html#doc_script_class_unary2_ops", null ],
      [ "Comparison operators", "doc_script_class_ops.html#doc_script_class_cmp_ops", null ],
      [ "Assignment operators", "doc_script_class_ops.html#doc_script_class_assign_ops", null ],
      [ "Binary operators", "doc_script_class_ops.html#doc_script_class_binary_ops", null ],
      [ "Index operators", "doc_script_class_ops.html#doc_script_class_index_op", null ],
      [ "Functor operator", "doc_script_class_ops.html#doc_script_class_call", null ],
      [ "Type conversion operators", "doc_script_class_ops.html#doc_script_class_conv", null ]
    ] ],
    [ "Property accessors", "doc_script_class_prop.html", [
      [ "Indexed property accessors", "doc_script_class_prop.html#doc_script_class_prop_index", null ]
    ] ],
    [ "Initialization of class members", "doc_script_class_memberinit.html", null ]
];

==> angelscript_2.37.0.zip: sdk/docs/manual/doc_script_class.js <==
var doc_script_class =
[
    [ "Script class overview", "doc_script_class_desc.html", null ],
    [ "Class constructors", "doc_script_class_construct.html", null ],
    [ "Initialization of class members", "doc_script_class_memberinit.html", null ],
    [ "Class destructor", "doc_script_class_destruct.html", null ],
    [ "Class methods", "doc_script_class_methods.html", [
      [ "Const methods", "doc_script_class_methods.html#doc_script_class_const", null ]
    ] ],
    [ "Inheritance and polymorphism", "doc_script_class_inheritance.html", [
      [ "Extra control with final, abstract, and override", "doc_script_class_inheritance.html#doc_script_class_inheritance_2", null ]
    ] ],
    [ "Protected and private class members", "doc_script_class_private.html", null ],
    [ "Operator overloads", "doc_script_class_ops.html", [
      [ "Prefixed unary operators", "doc_script_class_ops.html#doc_script_class_unary_ops", null ],
      [ "Postfixed unary operators", "doc_script_class_ops.html#doc_script_class_unary2_ops", null ],
      [ "Comparison operators", "doc_script_class_ops.html#doc_script_class_cmp_ops", null ],
      [ "Assignment operators", "doc_script_class_ops.html#doc_script_class_assign_ops", null ],
      [ "Binary operators", "doc_script_class_ops.html#doc_script_class_binary_ops", null ],
      [ "Index operators", "doc_script_class_ops.html#doc_script_class_index_op", null ],
      [ "Functor operator", "doc_script_class_ops.html#doc_script_class_call", null ],
      [ "Type conversion operators", "doc_script_class_ops.html#doc_script_class_conv", null ]
    ] ],
    [ "Property accessors", "doc_script_class_prop.html", [
      [ "Indexed property accessors", "doc_script_class_prop.html#doc_script_class_prop_index", null ]
    ] ]
];
